require 'seahorse/client/plugins/content_length.rb'
require 'aws-sdk-core/plugins/logging.rb'
require 'aws-sdk-core/plugins/param_converter.rb'
require 'aws-sdk-core/plugins/param_validator.rb'
require 'aws-sdk-core/plugins/helpful_socket_errors.rb'
require 'aws-sdk-core/plugins/retry_errors.rb'
require 'aws-sdk-core/plugins/global_configuration.rb'
require 'aws-sdk-core/plugins/response_paging.rb'
require 'aws-sdk-core/plugins/stub_responses.rb'
require 'aws-sdk-core/plugins/idempotency_token.rb'
require 'aws-sdk-core/plugins/jsonvalue_converter.rb'
require 'aws-sdk-core/plugins/protocols/api_gateway.rb'
require 'aws-sdk-core/plugins/api_key.rb'
require 'aws-sdk-core/plugins/apig_user_agent.rb'
require 'aws-sdk-core/plugins/apig_authorizer_token.rb'
require 'aws-sdk-core/plugins/apig_credentials_configuration.rb'
require 'alis-sdk-ruby/plugins/authorizer.rb'
require 'alis-sdk-ruby/plugins/apig_endpoint.rb'

Aws::Plugins::GlobalConfiguration.add_identifier(:alissdkruby)

module AlisSdkRuby
  class Client < Seahorse::Client::Base

    include Aws::ClientStubs

    @identifier = :alissdkruby

    set_api(ClientApi::API)

    add_plugin(Seahorse::Client::Plugins::ContentLength)
    add_plugin(Aws::Plugins::Logging)
    add_plugin(Aws::Plugins::ParamConverter)
    add_plugin(Aws::Plugins::ParamValidator)
    add_plugin(Aws::Plugins::HelpfulSocketErrors)
    add_plugin(Aws::Plugins::RetryErrors)
    add_plugin(Aws::Plugins::GlobalConfiguration)
    add_plugin(Aws::Plugins::ResponsePaging)
    add_plugin(Aws::Plugins::StubResponses)
    add_plugin(Aws::Plugins::IdempotencyToken)
    add_plugin(Aws::Plugins::JsonvalueConverter)
    add_plugin(Aws::Plugins::Protocols::ApiGateway)
    add_plugin(Aws::Plugins::ApiKey)
    add_plugin(Aws::Plugins::APIGUserAgent)
    add_plugin(Aws::Plugins::APIGAuthorizerToken)
    add_plugin(Aws::Plugins::APIGCredentialsConfiguration)
    add_plugin(AlisSdkRuby::Plugins::Authorizer)
    add_plugin(AlisSdkRuby::Plugins::APIGEndpoint)

    # @option options [String] :access_key_id
    #
    # @option options [String] :api_key
    #   When provided, `x-api-key` header will be injected with the value provided.
    #
    # @option options [Boolean] :convert_params (true)
    #   When `true`, an attempt is made to coerce request parameters into
    #   the required types.
    #
    # @option options [Aws::CredentialProvider] :credentials
    #   AWS Credentials options is only required when your API uses
    #   [AWS Signature Version 4](http://docs.aws.amazon.com/general/latest/gr/signature-version-4.html),
    #   more AWS Credentials Configuration Options are available [here](https://github.com/aws/aws-sdk-ruby#configuration).
    #
    # @option options [Aws::Log::Formatter] :log_formatter (Aws::Log::Formatter.default)
    #   The log formatter.
    #
    # @option options [Symbol] :log_level (:info)
    #   The log level to send messages to the `:logger` at.
    #
    # @option options [Logger] :logger
    #   The Logger instance to send log messages to.  If this option
    #   is not set, logging will be disabled.
    #
    # @option options [String] :profile
    #
    # @option options [Integer] :retry_limit (3)
    #   The maximum number of times to retry failed requests.  Only
    #   ~ 500 level server errors and certain ~ 400 level client errors
    #   are retried.  Generally, these are throttling errors, data
    #   checksum errors, networking errors, timeout errors and auth
    #   errors from expired credentials.
    #
    # @option options [String] :secret_access_key
    #
    # @option options [String] :session_token
    #
    # @option options [Boolean] :stub_responses (false)
    #   Causes the client to return stubbed responses. By default
    #   fake responses are generated and returned. You can specify
    #   the response data to return or errors to raise by calling
    #   {ClientStubs#stub_responses}. See {ClientStubs} for more information.
    #
    #   ** Please note ** When response stubbing is enabled, no HTTP
    #   requests are made, and retries are disabled.
    #
    # @option options [Boolean] :validate_params (true)
    #   When `true`, request parameters are validated before
    #   sending the request.
    #
    def initialize(*args)
      super
    end

    # @!group API Operations

    # @option params [required, String] :article_id
    #
    # @return [Types::GetArticlesArticle_idResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetArticlesArticle_idResponse#article_content #article_content} => Types::ArticleContent
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_articles_article_id({
    #     article_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.article_content.article_id #=> String
    #   resp.article_content.body #=> String
    #   resp.article_content.created_at #=> Integer
    #   resp.article_content.eye_catch_url #=> String
    #   resp.article_content.overview #=> String
    #   resp.article_content.title #=> String
    #   resp.article_content.user_id #=> String
    #
    # @overload get_articles_article_id(params = {})
    # @param [Hash] params ({})
    def get_articles_article_id(params = {}, options = {})
      req = build_request(:get_articles_article_id, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Types::GetArticlesArticle_idAlistokenResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetArticlesArticle_idAlistokenResponse#model69304a #model69304a} => Types::MODEL69304a
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_articles_article_id_alistoken({
    #     article_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.model69304a.alistoken #=> Float
    #
    # @overload get_articles_article_id_alistoken(params = {})
    # @param [Hash] params ({})
    def get_articles_article_id_alistoken(params = {}, options = {})
      req = build_request(:get_articles_article_id_alistoken, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Types::GetArticlesArticle_idLikesResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetArticlesArticle_idLikesResponse#mode_ld_25993 #mode_ld_25993} => Types::MODELd25993
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_articles_article_id_likes({
    #     article_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.mode_ld_25993.count #=> Float
    #
    # @overload get_articles_article_id_likes(params = {})
    # @param [Hash] params ({})
    def get_articles_article_id_likes(params = {}, options = {})
      req = build_request(:get_articles_article_id_likes, params)
      req.send_request(options)
    end

    # @option params [String] :article_id
    #
    # @option params [String] :limit
    #
    # @option params [String] :score
    #
    # @return [Types::GetArticlesPopularResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetArticlesPopularResponse#array_of_article_info #array_of_article_info} => Array&lt;Types::ArticleInfo&gt;
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_articles_popular({
    #     article_id: "__string",
    #     limit: "__string",
    #     score: "__string",
    #   })
    #
    # @example Response structure
    #
    #   resp.array_of_article_info #=> Array
    #   resp.array_of_article_info[0].article_id #=> String
    #   resp.array_of_article_info[0].created_at #=> Integer
    #   resp.array_of_article_info[0].eye_catch_url #=> String
    #   resp.array_of_article_info[0].overview #=> String
    #   resp.array_of_article_info[0].title #=> String
    #   resp.array_of_article_info[0].user_id #=> String
    #
    # @overload get_articles_popular(params = {})
    # @param [Hash] params ({})
    def get_articles_popular(params = {}, options = {})
      req = build_request(:get_articles_popular, params)
      req.send_request(options)
    end

    # @option params [String] :article_id
    #
    # @option params [String] :limit
    #
    # @option params [String] :sort_key
    #
    # @return [Types::GetArticlesRecentResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetArticlesRecentResponse#array_of_article_info #array_of_article_info} => Array&lt;Types::ArticleInfo&gt;
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_articles_recent({
    #     article_id: "__string",
    #     limit: "__string",
    #     sort_key: "__string",
    #   })
    #
    # @example Response structure
    #
    #   resp.array_of_article_info #=> Array
    #   resp.array_of_article_info[0].article_id #=> String
    #   resp.array_of_article_info[0].created_at #=> Integer
    #   resp.array_of_article_info[0].eye_catch_url #=> String
    #   resp.array_of_article_info[0].overview #=> String
    #   resp.array_of_article_info[0].title #=> String
    #   resp.array_of_article_info[0].user_id #=> String
    #
    # @overload get_articles_recent(params = {})
    # @param [Hash] params ({})
    def get_articles_recent(params = {}, options = {})
      req = build_request(:get_articles_recent, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Types::GetMeArticlesArticle_idDraftsResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeArticlesArticle_idDraftsResponse#article_content #article_content} => Types::ArticleContent
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_me_articles_article_id_drafts({
    #     article_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.article_content.article_id #=> String
    #   resp.article_content.body #=> String
    #   resp.article_content.created_at #=> Integer
    #   resp.article_content.eye_catch_url #=> String
    #   resp.article_content.overview #=> String
    #   resp.article_content.title #=> String
    #   resp.article_content.user_id #=> String
    #
    # @overload get_me_articles_article_id_drafts(params = {})
    # @param [Hash] params ({})
    def get_me_articles_article_id_drafts(params = {}, options = {})
      req = build_request(:get_me_articles_article_id_drafts, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Types::GetMeArticlesArticle_idLikeResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeArticlesArticle_idLikeResponse#model84cbde #model84cbde} => Types::MODEL84cbde
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_me_articles_article_id_like({
    #     article_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.model84cbde.liked #=> Boolean
    #
    # @overload get_me_articles_article_id_like(params = {})
    # @param [Hash] params ({})
    def get_me_articles_article_id_like(params = {}, options = {})
      req = build_request(:get_me_articles_article_id_like, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Types::GetMeArticlesArticle_idPublicResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeArticlesArticle_idPublicResponse#article_content #article_content} => Types::ArticleContent
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_me_articles_article_id_public({
    #     article_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.article_content.article_id #=> String
    #   resp.article_content.body #=> String
    #   resp.article_content.created_at #=> Integer
    #   resp.article_content.eye_catch_url #=> String
    #   resp.article_content.overview #=> String
    #   resp.article_content.title #=> String
    #   resp.article_content.user_id #=> String
    #
    # @overload get_me_articles_article_id_public(params = {})
    # @param [Hash] params ({})
    def get_me_articles_article_id_public(params = {}, options = {})
      req = build_request(:get_me_articles_article_id_public, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Types::GetMeArticlesArticle_idPublicEditResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeArticlesArticle_idPublicEditResponse#article_content #article_content} => Types::ArticleContent
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_me_articles_article_id_public_edit({
    #     article_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.article_content.article_id #=> String
    #   resp.article_content.body #=> String
    #   resp.article_content.created_at #=> Integer
    #   resp.article_content.eye_catch_url #=> String
    #   resp.article_content.overview #=> String
    #   resp.article_content.title #=> String
    #   resp.article_content.user_id #=> String
    #
    # @overload get_me_articles_article_id_public_edit(params = {})
    # @param [Hash] params ({})
    def get_me_articles_article_id_public_edit(params = {}, options = {})
      req = build_request(:get_me_articles_article_id_public_edit, params)
      req.send_request(options)
    end

    # @option params [String] :article_id
    #
    # @option params [String] :limit
    #
    # @option params [String] :sort_key
    #
    # @return [Types::GetMeArticlesDraftsResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeArticlesDraftsResponse#array_of_article_info #array_of_article_info} => Array&lt;Types::ArticleInfo&gt;
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_me_articles_drafts({
    #     article_id: "__string",
    #     limit: "__string",
    #     sort_key: "__string",
    #   })
    #
    # @example Response structure
    #
    #   resp.array_of_article_info #=> Array
    #   resp.array_of_article_info[0].article_id #=> String
    #   resp.array_of_article_info[0].created_at #=> Integer
    #   resp.array_of_article_info[0].eye_catch_url #=> String
    #   resp.array_of_article_info[0].overview #=> String
    #   resp.array_of_article_info[0].title #=> String
    #   resp.array_of_article_info[0].user_id #=> String
    #
    # @overload get_me_articles_drafts(params = {})
    # @param [Hash] params ({})
    def get_me_articles_drafts(params = {}, options = {})
      req = build_request(:get_me_articles_drafts, params)
      req.send_request(options)
    end

    # @option params [String] :article_id
    #
    # @option params [String] :limit
    #
    # @option params [String] :sort_key
    #
    # @return [Types::GetMeArticlesPublicResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeArticlesPublicResponse#array_of_article_info #array_of_article_info} => Array&lt;Types::ArticleInfo&gt;
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_me_articles_public({
    #     article_id: "__string",
    #     limit: "__string",
    #     sort_key: "__string",
    #   })
    #
    # @example Response structure
    #
    #   resp.array_of_article_info #=> Array
    #   resp.array_of_article_info[0].article_id #=> String
    #   resp.array_of_article_info[0].created_at #=> Integer
    #   resp.array_of_article_info[0].eye_catch_url #=> String
    #   resp.array_of_article_info[0].overview #=> String
    #   resp.array_of_article_info[0].title #=> String
    #   resp.array_of_article_info[0].user_id #=> String
    #
    # @overload get_me_articles_public(params = {})
    # @param [Hash] params ({})
    def get_me_articles_public(params = {}, options = {})
      req = build_request(:get_me_articles_public, params)
      req.send_request(options)
    end

    # @return [Types::GetMeInfoResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeInfoResponse#user_info #user_info} => Types::UserInfo
    #
    # @example Response structure
    #
    #   resp.user_info.icon_image_url #=> String
    #   resp.user_info.self_introduction #=> String
    #   resp.user_info.user_display_name #=> String
    #   resp.user_info.user_id #=> String
    #
    # @overload get_me_info(params = {})
    # @param [Hash] params ({})
    def get_me_info(params = {}, options = {})
      req = build_request(:get_me_info, params)
      req.send_request(options)
    end

    # @return [Types::GetMeNotificationsResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeNotificationsResponse#array_of_notification #array_of_notification} => Array&lt;Types::Notification&gt;
    #
    # @example Response structure
    #
    #   resp.array_of_notification #=> Array
    #   resp.array_of_notification[0].acted_user_id #=> String
    #   resp.array_of_notification[0].created_at #=> Integer
    #   resp.array_of_notification[0].sort_key #=> Integer
    #   resp.array_of_notification[0].type #=> String
    #   resp.array_of_notification[0].user_id #=> String
    #
    # @overload get_me_notifications(params = {})
    # @param [Hash] params ({})
    def get_me_notifications(params = {}, options = {})
      req = build_request(:get_me_notifications, params)
      req.send_request(options)
    end

    # @return [Types::GetMeUnread_notification_managersResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeUnread_notification_managersResponse#mode_lc_40ebe #mode_lc_40ebe} => Types::MODELc40ebe
    #
    # @example Response structure
    #
    #   resp.mode_lc_40ebe.unread #=> Boolean
    #
    # @overload get_me_unread_notification_managers(params = {})
    # @param [Hash] params ({})
    def get_me_unread_notification_managers(params = {}, options = {})
      req = build_request(:get_me_unread_notification_managers, params)
      req.send_request(options)
    end

    # @return [Types::GetMeWalletBalanceResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetMeWalletBalanceResponse#me_wallet_balance #me_wallet_balance} => Types::MeWalletBalance
    #
    # @example Response structure
    #
    #   resp.me_wallet_balance.private_eth_address #=> String
    #
    # @overload get_me_wallet_balance(params = {})
    # @param [Hash] params ({})
    def get_me_wallet_balance(params = {}, options = {})
      req = build_request(:get_me_wallet_balance, params)
      req.send_request(options)
    end

    # @option params [String] :article_id
    #
    # @option params [String] :limit
    #
    # @option params [String] :sort_key
    #
    # @option params [required, String] :user_id
    #
    # @return [Types::GetUsersUser_idArticlesPublicResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetUsersUser_idArticlesPublicResponse#array_of_article_info #array_of_article_info} => Array&lt;Types::ArticleInfo&gt;
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_users_user_id_articles_public({
    #     article_id: "__string",
    #     limit: "__string",
    #     sort_key: "__string",
    #     user_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.array_of_article_info #=> Array
    #   resp.array_of_article_info[0].article_id #=> String
    #   resp.array_of_article_info[0].created_at #=> Integer
    #   resp.array_of_article_info[0].eye_catch_url #=> String
    #   resp.array_of_article_info[0].overview #=> String
    #   resp.array_of_article_info[0].title #=> String
    #   resp.array_of_article_info[0].user_id #=> String
    #
    # @overload get_users_user_id_articles_public(params = {})
    # @param [Hash] params ({})
    def get_users_user_id_articles_public(params = {}, options = {})
      req = build_request(:get_users_user_id_articles_public, params)
      req.send_request(options)
    end

    # @option params [required, String] :user_id
    #
    # @return [Types::GetUsersUser_idInfoResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::GetUsersUser_idInfoResponse#user_info #user_info} => Types::UserInfo
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.get_users_user_id_info({
    #     user_id: "__string", # required
    #   })
    #
    # @example Response structure
    #
    #   resp.user_info.icon_image_url #=> String
    #   resp.user_info.self_introduction #=> String
    #   resp.user_info.user_display_name #=> String
    #   resp.user_info.user_id #=> String
    #
    # @overload get_users_user_id_info(params = {})
    # @param [Hash] params ({})
    def get_users_user_id_info(params = {}, options = {})
      req = build_request(:get_users_user_id_info, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.post_me_articles_article_id_fraud({
    #     article_id: "__string", # required
    #   })
    #
    # @overload post_me_articles_article_id_fraud(params = {})
    # @param [Hash] params ({})
    def post_me_articles_article_id_fraud(params = {}, options = {})
      req = build_request(:post_me_articles_article_id_fraud, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @option params [required, Types::ArticleImage] :article_image
    #
    # @return [Types::PostMeArticlesArticle_idImagesResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::PostMeArticlesArticle_idImagesResponse#mode_ld_06bfe #mode_ld_06bfe} => Types::MODELd06bfe
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.post_me_articles_article_id_images({
    #     article_id: "__string", # required
    #     article_image: { # required
    #       article_image: "__string",
    #     },
    #   })
    #
    # @example Response structure
    #
    #   resp.mode_ld_06bfe.image_url #=> String
    #
    # @overload post_me_articles_article_id_images(params = {})
    # @param [Hash] params ({})
    def post_me_articles_article_id_images(params = {}, options = {})
      req = build_request(:post_me_articles_article_id_images, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.post_me_articles_article_id_like({
    #     article_id: "__string", # required
    #   })
    #
    # @overload post_me_articles_article_id_like(params = {})
    # @param [Hash] params ({})
    def post_me_articles_article_id_like(params = {}, options = {})
      req = build_request(:post_me_articles_article_id_like, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.post_me_articles_article_id_pv({
    #     article_id: "__string", # required
    #   })
    #
    # @overload post_me_articles_article_id_pv(params = {})
    # @param [Hash] params ({})
    def post_me_articles_article_id_pv(params = {}, options = {})
      req = build_request(:post_me_articles_article_id_pv, params)
      req.send_request(options)
    end

    # @option params [required, Types::MeArticlesDraftsCreate] :me_articles_drafts_create
    #
    # @return [Types::PostMeArticlesDraftsResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::PostMeArticlesDraftsResponse#mode_lcde_73d #mode_lcde_73d} => Types::MODELcde73d
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.post_me_articles_drafts({
    #     me_articles_drafts_create: { # required
    #       body: "__string",
    #       eye_catch_url: "__string",
    #       overview: "__string",
    #       title: "__string",
    #     },
    #   })
    #
    # @example Response structure
    #
    #   resp.mode_lcde_73d.article_id #=> String
    #
    # @overload post_me_articles_drafts(params = {})
    # @param [Hash] params ({})
    def post_me_articles_drafts(params = {}, options = {})
      req = build_request(:post_me_articles_drafts, params)
      req.send_request(options)
    end

    # @option params [required, Types::MeInfoIcon] :me_info_icon
    #
    # @return [Types::PostMeInfoIconResponse] Returns a {Seahorse::Client::Response response} object which responds to the following methods:
    #
    #   * {Types::PostMeInfoIconResponse#mode_la_08eaf #mode_la_08eaf} => Types::MODELa08eaf
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.post_me_info_icon({
    #     me_info_icon: { # required
    #       icon_image: "__string",
    #     },
    #   })
    #
    # @example Response structure
    #
    #   resp.mode_la_08eaf.image_url #=> String
    #
    # @overload post_me_info_icon(params = {})
    # @param [Hash] params ({})
    def post_me_info_icon(params = {}, options = {})
      req = build_request(:post_me_info_icon, params)
      req.send_request(options)
    end

    # @option params [required, Types::MeArticlesDraftsCreate] :me_articles_drafts_create
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.put_me_articles_article_id_drafts({
    #     me_articles_drafts_create: { # required
    #       body: "__string",
    #       eye_catch_url: "__string",
    #       overview: "__string",
    #       title: "__string",
    #     },
    #   })
    #
    # @overload put_me_articles_article_id_drafts(params = {})
    # @param [Hash] params ({})
    def put_me_articles_article_id_drafts(params = {}, options = {})
      req = build_request(:put_me_articles_article_id_drafts, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.put_me_articles_article_id_drafts_publish({
    #     article_id: "__string", # required
    #   })
    #
    # @overload put_me_articles_article_id_drafts_publish(params = {})
    # @param [Hash] params ({})
    def put_me_articles_article_id_drafts_publish(params = {}, options = {})
      req = build_request(:put_me_articles_article_id_drafts_publish, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @option params [required, Types::UpdateArticle] :update_article
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.put_me_articles_article_id_public({
    #     article_id: "__string", # required
    #     update_article: { # required
    #       body: "__string",
    #       eye_catch_url: "__string",
    #       overview: "__string",
    #       title: "__string",
    #     },
    #   })
    #
    # @overload put_me_articles_article_id_public(params = {})
    # @param [Hash] params ({})
    def put_me_articles_article_id_public(params = {}, options = {})
      req = build_request(:put_me_articles_article_id_public, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.put_me_articles_article_id_public_republish({
    #     article_id: "__string", # required
    #   })
    #
    # @overload put_me_articles_article_id_public_republish(params = {})
    # @param [Hash] params ({})
    def put_me_articles_article_id_public_republish(params = {}, options = {})
      req = build_request(:put_me_articles_article_id_public_republish, params)
      req.send_request(options)
    end

    # @option params [required, String] :article_id
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.put_me_articles_article_id_public_unpublish({
    #     article_id: "__string", # required
    #   })
    #
    # @overload put_me_articles_article_id_public_unpublish(params = {})
    # @param [Hash] params ({})
    def put_me_articles_article_id_public_unpublish(params = {}, options = {})
      req = build_request(:put_me_articles_article_id_public_unpublish, params)
      req.send_request(options)
    end

    # @option params [required, Types::MeInfoUpdate] :me_info_update
    #
    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @example Request syntax with placeholder values
    #
    #   resp = client.put_me_info({
    #     me_info_update: { # required
    #       self_introduction: "__string",
    #       user_display_name: "__string",
    #     },
    #   })
    #
    # @overload put_me_info(params = {})
    # @param [Hash] params ({})
    def put_me_info(params = {}, options = {})
      req = build_request(:put_me_info, params)
      req.send_request(options)
    end

    # @return [Struct] Returns an empty {Seahorse::Client::Response response}.
    #
    # @overload put_me_unread_notification_managers(params = {})
    # @param [Hash] params ({})
    def put_me_unread_notification_managers(params = {}, options = {})
      req = build_request(:put_me_unread_notification_managers, params)
      req.send_request(options)
    end

    # @!endgroup

    # @param params ({})
    # @api private
    def build_request(operation_name, params = {})
      handlers = @handlers.for(operation_name)
      authorizer = nil
      if config.api.operation(operation_name).authorizer
        authorizer_name = config.api.operation(operation_name).authorizer
        config.api.authorizers.each do |_, auth|
          authorizer = auth if auth.name == authorizer_name
        end
      end
      context = Seahorse::Client::RequestContext.new(
        operation_name: operation_name,
        operation: config.api.operation(operation_name),
        authorizer: authorizer,
        client: self,
        params: params,
        config: config)
      context[:gem_name] = 'alis-sdk-ruby'
      context[:gem_version] = '0.13.0'
      Seahorse::Client::Request.new(handlers, context)
    end

    # @api private
    # @deprecated
    def waiter_names
      []
    end

    class << self

      # @api private
      attr_reader :identifier

      # @api private
      def errors_module
        Errors
      end

    end
  end
end
